## host definition file - where you specify the physical configuration for all of your various host types
## role: the type of 'thing' it is, currently used options are controller, compute, storage, and container.
## macs: python list of all the macs belonging to this type of host
## interface: the interface that you want to use when PXE booting (should be DHCP enabled)
## proxy: if you have a static, external proxy, place the address here.  Otherwise use pull_from_mine to use the internal one
## root_password: preseeded password.  See mkpasswd.
## ntp_server: the ntp server that you want to use for the preseed process
## disk:  the disk you want to install the OS on to
## ipmi_addresses: the addresses for the IPMI interfaces on these devices

## kvm_disk_config - CONTROLLER ONLY
## type: raidX, where X is 1 or 10.  raid1 must have 2 members entries in the list.  raid10 must have a multiple of 2 members in the list
## type: standard.  May pass a device (e.g. /dev/sdb) as a single member, or pass the special value 'rootfs' as a single member, which will
## just create a directory on the root filesystem at /kvm

## networks: specify how you want your final, post-deployment network to be configured.
##   bridge: true if this host will be used as a hypervisor
##   bonds: false if there are no LAGG iterfaces,
##   bonds:
##     bond0:
##       - slaveX
##   if there are
##   vlan: true if you will be tagging on this host
##   interface entries: top level definition will be the name of the physical interface
##     network: the network to which it will bind (must match answers.sls)
##     primary: true if it will get DHCP, otherwise false
##     bridge: true if a bridged interface, otherwise false
##     vlan: vlanID if a vlan, otherwise false.

hosts:
  controllerv1:
    role: controller
    os: ubuntu1804
    macs:
      - 0c:c4:7a:f9:89:9c
      - 0c:c4:7a:f9:89:b0
    interface: ens2f0np0
    proxy: pull_from_mine
    root_password_crypted: $6$sSXsfvsKhwy$RrINorhH4lNeNdNbi/vHqCAApM8ID9Lhvmzs6OQMO4791igXZIrhWg6Kyi7XPRGhIZOgGUdCx4prarhaV62id0
    ntp_server: 0.us.pool.ntp.org
    disk: SAMSUNG MZ7KM1T9
    ipmi_addresses:
      - 10.10.0.14
      - 10.10.0.15
    kvm_disk_config:
      type: raid10
      members:
        - /dev/sdc
        - /dev/sdd
        - /dev/sde
        - /dev/sdf
        - /dev/sdg
        - /dev/sdh
        - /dev/sdi
        - /dev/sdj
    networks:
      bonds: false
      bridge: true
      vlan: false
      interfaces:
        ens2f0np0:
          network: management
          primary: true
          bridge: true
          vlan: false
        ens2f1np1:
          network: sfe
          primary: false
          bridge: true
          vlan: false
        ens2f3np3:
          network: public
          primary: false
          bridge: true
          vlan: false
        ens2f2np2:
          network: private
          primary: false
          bridge: true
          vlan: false
  controllerv2:
    role: controller
    os: ubuntu1804
    macs:
      - 0c:c4:7a:fb:ea:30
      - 0c:c4:7a:fb:eb:88
      - 0c:c4:7a:fb:eb:b0
      - 0c:c4:7a:fb:eb:80
      - 0c:c4:7a:fb:eb:b8
      - 0c:c4:7a:fb:eb:7c
    interface: enp97s0f0
    proxy: pull_from_mine
    root_password_crypted: $6$sSXsfvsKhwy$RrINorhH4lNeNdNbi/vHqCAApM8ID9Lhvmzs6OQMO4791igXZIrhWg6Kyi7XPRGhIZOgGUdCx4prarhaV62id0
    ntp_server: 0.us.pool.ntp.org
    disk: Micron_9200_MTFDHAL6T4TCU
    ipmi_addresses:
      - 10.10.0.8
      - 10.10.0.9
      - 10.10.0.16
      - 10.10.0.17
      - 10.10.0.18
      - 10.10.0.19
    kvm_disk_config:
      type: standard
      members:
        - rootfs
    networks:
      bonds: false
      bridge: true
      vlan: false
      interfaces:
        enp97s0f0:
          network: management
          primary: true
          bridge: true
          vlan: false
        enp113s0f0:
          network: sfe
          primary: false
          bridge: true
          vlan: false
        enp97s0f1:
          network: public
          primary: false
          bridge: true
          vlan: false
        enp113s0f1:
          network: private
          primary: false
          bridge: true
          vlan: false
  controllerv3:
    role: controller
    os: ubuntu1804
    macs:
      - 0c:c4:7a:a5:cb:2e
    interface: ens2f0np0
    proxy: pull_from_mine
    root_password_crypted: $6$sSXsfvsKhwy$RrINorhH4lNeNdNbi/vHqCAApM8ID9Lhvmzs6OQMO4791igXZIrhWg6Kyi7XPRGhIZOgGUdCx4prarhaV62id0
    ntp_server: 0.us.pool.ntp.org
    disk: INTEL SSDSC2BA01
    ipmi_addresses:
      - 10.10.0.13
    kvm_disk_config:
      type: raid10
      members:
        - /dev/sdc
        - /dev/sdd
        - /dev/sde
        - /dev/sdf
        - /dev/sdg
        - /dev/sdh
        - /dev/sdi
        - /dev/sdj
    networks:
      bonds: false
      bridge: true
      vlan: false
      interfaces:
        ens2f0np0:
          network: management
          primary: true
          bridge: true
          vlan: false
        ens2f1np1:
          network: sfe
          primary: false
          bridge: true
          vlan: false
        ens2f3np3:
          network: public
          primary: false
          bridge: true
          vlan: false
        ens2f2np2:
          network: private
          primary: false
          bridge: true
          vlan: false
  controllerv4:
    role: controller
    os: ubuntu1804
    macs:
      - ac:1f:6b:c3:b5:d8
      - ac:1f:6b:c3:b5:e8
      - ac:1f:6b:c3:b2:e8
      - ac:1f:6b:c3:b2:d4
#      - ac:1f:6b:c3:b5:90
      - ac:1f:6b:c3:b5:f0
    interface: enp129s0f1
    proxy: pull_from_mine
    root_password_crypted: $6$sSXsfvsKhwy$RrINorhH4lNeNdNbi/vHqCAApM8ID9Lhvmzs6OQMO4791igXZIrhWg6Kyi7XPRGhIZOgGUdCx4prarhaV62id0
    ntp_server: 0.us.pool.ntp.org
    disk: SAMSUNG MZWLL6T4HMLA
    ipmi_addresses:
      - 10.10.0.2
      - 10.10.0.3
      - 10.10.0.4
      - 10.10.0.5
#      - 10.10.0.6
      - 10.10.0.7
    kvm_disk_config:
      type: standard
      members:
        - rootfs
    networks:
      bonds: false
      bridge: true
      vlan: false
      interfaces:
        enp129s0f1:
          network: management
          primary: true
          bridge: true
          vlan: false
        enp129s0f0:
          network: sfe
          primary: false
          bridge: true
          vlan: false
        enp193s0f0:
          network: public
          primary: false
          bridge: true
          vlan: false
        enp193s0f1:
          network: private
          primary: false
          bridge: true
          vlan: false
  storagev1:
    role: storage
    os: ubuntu1804
    macs:
#      - 0c:c4:7a:22:ad:a8 dev env
#      - 0c:c4:7a:22:ad:20 dev env
#      - 0c:c4:7a:22:ad:94 dev env
#      - 0c:c4:7a:22:ad:48 dev env
#      - 0c:c4:7a:22:ad:b0 dev env
#      - 0c:c4:7a:22:ad:0c dev env
      - 0c:c4:7a:22:ad:98
#      - 0c:c4:7a:22:ad:2c Storagev3
      - 0c:c4:7a:22:ad:ac
      - 0c:c4:7a:22:ad:30
      - 0c:c4:7a:22:ad:4c
      - 0c:c4:7a:22:ad:44
      - 0c:c4:7a:22:ad:58
      - 0c:c4:7a:22:ad:1c
      - 0c:c4:7a:22:ad:38
      - 0c:c4:7a:22:ad:90
    interface: ens5f0
    proxy: pull_from_mine
    root_password_crypted: $6$sSXsfvsKhwy$RrINorhH4lNeNdNbi/vHqCAApM8ID9Lhvmzs6OQMO4791igXZIrhWg6Kyi7XPRGhIZOgGUdCx4prarhaV62id0
    ntp_server: 0.us.pool.ntp.org
    disk: INTEL SSDSC2BA40
    ipmi_addresses:
#      - 10.10.2.20 dev env
#      - 10.10.2.21 dev env
#      - 10.10.2.22 dev env
#      - 10.10.2.23 dev env
#      - 10.10.2.24 dev env
#      - 10.10.2.25 dev env
      - 10.10.2.26
#      - 10.10.2.27 Storagev3
      - 10.10.2.28
      - 10.10.2.29
      - 10.10.2.30
      - 10.10.2.31
      - 10.10.2.32
      - 10.10.2.33
      - 10.10.2.34
      - 10.10.2.35
    networks:
      bonds:
        bond0:
          - ens7f0np0
          - ens7f1np1
        bond1:
          - ens5f1
          - ens5f2
          - ens5f3
      bridge: false
      vlan: false
      interfaces:
        ens5f0:
          network: management
          primary: true
          bridge: false
          vlan: false
        bond0:
          network: sfe
          primary: false
          bridge: false
          vlan: false
          bond: true
        bond1:
          network: sbe
          primary: false
          bridge: false
          vlan: false
          bond: true
  storagev2:
    role: storage
    os: ubuntu1804
    macs:
      - ac:1f:6b:4e:35:00
      - ac:1f:6b:4d:ae:d4
      - ac:1f:6b:4d:af:ac
      - ac:1f:6b:4e:34:ec
      - ac:1f:6b:4e:34:84
      - ac:1f:6b:4e:34:e6
      - ac:1f:6b:4e:a0:ce
      - ac:1f:6b:4d:af:54
      - ac:1f:6b:4e:34:ee
      - ac:1f:6b:4e:34:e0
      - ac:1f:6b:4d:ae:dc
      - ac:1f:6b:4e:35:2c
    interface: enp94s0f0
    proxy: pull_from_mine
    root_password_crypted: $6$sSXsfvsKhwy$RrINorhH4lNeNdNbi/vHqCAApM8ID9Lhvmzs6OQMO4791igXZIrhWg6Kyi7XPRGhIZOgGUdCx4prarhaV62id0
    ntp_server: 0.us.pool.ntp.org
    disk: INTEL SSDPED1K750GA
    ipmi_addresses:
      - 10.10.2.36
      - 10.10.2.37
      - 10.10.2.38
      - 10.10.2.39
      - 10.10.2.40
      - 10.10.2.41
      - 10.10.2.42
      - 10.10.2.43
      - 10.10.2.44
      - 10.10.2.45
      - 10.10.2.46
      - 10.10.2.47
    networks:
      bonds: false
      bridge: false
      vlan: false
      interfaces:
        enp94s0f0:
          network: management
          primary: true
          bridge: false
          vlan: false
        enp94s0f1:
          network: sfe
          primary: false
          bridge: false
          vlan: false
        enp175s0f0:
          network: sbe
          primary: false
          bridge: false
          vlan: false
  storagev3:
    role: storage
    os: ubuntu1804
    macs:
      - 0c:c4:7a:22:ad:2c
    interface: ens5f0
    proxy: pull_from_mine
    root_password_crypted: $6$sSXsfvsKhwy$RrINorhH4lNeNdNbi/vHqCAApM8ID9Lhvmzs6OQMO4791igXZIrhWg6Kyi7XPRGhIZOgGUdCx4prarhaV62id0
    ntp_server: 0.us.pool.ntp.org
    disk: INTEL SSDSC2BA40
    ipmi_addresses:
      - 10.10.2.27
    networks:
      bonds:
        bond0:
          - ens7f0np0
          - ens7f1np1
        bond1:
          - ens5f1
          - ens5f2
          - ens5f3
      bridge: false
      vlan: false
      interfaces:
        ens5f0:
          network: management
          primary: true
          bridge: false
          vlan: false
        bond0:
          network: sfe
          primary: false
          bridge: false
          vlan: false
          bond: true
        bond1:
          network: sbe
          primary: false
          bridge: false
          vlan: false
          bond: true
  storagev4:
    role: storage
    os: ubuntu1804
    macs:
      - ac:1f:6b:4d:ae:fc
      - ac:1f:6b:4e:34:e4
      - ac:1f:6b:4e:34:e8
      - ac:1f:6b:4d:af:0c
      - ac:1f:6b:4d:af:46
      - ac:1f:6b:4d:af:44
      - ac:1f:6b:4d:af:68
      - ac:1f:6b:4e:a1:5a
      - ac:1f:6b:4d:ae:d0
      - ac:1f:6b:4d:af:34
      - ac:1f:6b:4e:34:ea
      - ac:1f:6b:c6:01:e8
    interface: enp94s0f0
    proxy: pull_from_mine
    root_password_crypted: $6$sSXsfvsKhwy$RrINorhH4lNeNdNbi/vHqCAApM8ID9Lhvmzs6OQMO4791igXZIrhWg6Kyi7XPRGhIZOgGUdCx4prarhaV62id0
    ntp_server: 0.us.pool.ntp.org
    disk: INTEL SSDPED1K750GA
    ipmi_addresses:
      - 10.10.2.48
      - 10.10.2.49
      - 10.10.2.50
      - 10.10.2.51
      - 10.10.2.52
      - 10.10.2.53
      - 10.10.2.54
      - 10.10.2.55
      - 10.10.2.56
      - 10.10.2.57
      - 10.10.2.58
      - 10.10.2.59
    networks:
      bonds: false
      bridge: false
      vlan: false
      interfaces:
        enp94s0f0:
          network: management
          primary: true
          bridge: false
          vlan: false
        enp94s0f1:
          network: sfe
          primary: false
          bridge: false
          vlan: false
        enp175s0f0:
          network: sbe
          primary: false
          bridge: false
          vlan: false
  computev1:
    role: compute
    os: ubuntu1804
    macs:
#      - 0c:c4:7a:3b:6e:d0 dev container
#      - 0c:c4:7a:a5:cc:16 dev env
#      - 0c:c4:7a:a5:cb:16 dev env
#      - 0c:c4:7a:a5:d0:c2 dev env
#      - 0c:c4:7a:a5:cd:86 dev env
#      - 0c:c4:7a:a5:cb:1a dev env
#      - 0c:c4:7a:a5:cc:2e dev env
#      - 0c:c4:7a:3b:6e:6c dev env
      - 0c:c4:7a:a5:cc:02
      - 0c:c4:7a:3b:6f:f0
      - 0c:c4:7a:a5:cc:e6
      - 0c:c4:7a:a5:cf:7a
      - 0c:c4:7a:a5:cc:66
      - 0c:c4:7a:a5:cb:0e
      - 0c:c4:7a:a5:cb:06
      - 0c:c4:7a:a5:cb:4e
      - 0c:c4:7a:f9:87:b0
      - 0c:c4:7a:f9:87:bc
      - 0c:c4:7a:f9:8e:08
      - 0c:c4:7a:f9:8e:14
      - 0c:c4:7a:f9:8d:fc
      - 0c:c4:7a:f9:8e:10
      - 0c:c4:7a:f9:8e:04
#      - 0c:c4:7a:f9:8e:18 used for prod containers currently
    interface: ens2f0np0
    proxy: pull_from_mine
    root_password_crypted: $6$sSXsfvsKhwy$RrINorhH4lNeNdNbi/vHqCAApM8ID9Lhvmzs6OQMO4791igXZIrhWg6Kyi7XPRGhIZOgGUdCx4prarhaV62id0
    ntp_server: 0.us.pool.ntp.org
    disk: INTEL SSDSC2BA40
    ipmi_addresses:
#      - 10.10.0.20 dev container
#      - 10.10.0.21 dev env
#      - 10.10.0.22 dev env
#      - 10.10.0.23 dev env
#      - 10.10.0.24 dev env
#      - 10.10.0.25 dev env
#      - 10.10.0.26 dev env
#      - 10.10.0.27 dev env
      - 10.10.0.28
      - 10.10.0.29
      - 10.10.0.30
      - 10.10.0.31
      - 10.10.0.32
      - 10.10.0.33
      - 10.10.0.34
      - 10.10.0.35
      - 10.10.0.36
      - 10.10.0.37
      - 10.10.0.38
      - 10.10.0.39
      - 10.10.0.40
      - 10.10.0.41
      - 10.10.0.42
#      - 10.10.0.43 used for prod containers currently
    networks:
      bonds: false
      bridge: false
      vlan: false
      interfaces:
        ens2f0np0:
          network: management
          primary: true
          bridge: false
          vlan: false
        ens2f1np1:
          network: sfe
          primary: false
          bridge: false
          vlan: false
        ens2f3np3:
          network: public
          primary: false
          bridge: false
          vlan: false
        ens2f2np2:
          network: private
          primary: false
          bridge: false
          vlan: false
  computev2:
    role: compute
    os: ubuntu1804
    macs:
#      - 0c:c4:7a:fe:30:0c
      - 0c:c4:7a:fe:2e:04
      - 0c:c4:7a:fe:30:30
      - 0c:c4:7a:fe:2e:80
      - 0c:c4:7a:fe:2e:50
      - 0c:c4:7a:fe:2e:a4
      - 0c:c4:7a:fe:30:2c
      - 0c:c4:7a:fe:2e:44
      - 0c:c4:7a:fe:2f:a0
      - 0c:c4:7a:fe:2e:2c
      - 0c:c4:7a:fe:2c:ec
      - 0c:c4:7a:fe:2e:b0
    interface: enp97s0f0
    proxy: pull_from_mine
    root_password_crypted: $6$sSXsfvsKhwy$RrINorhH4lNeNdNbi/vHqCAApM8ID9Lhvmzs6OQMO4791igXZIrhWg6Kyi7XPRGhIZOgGUdCx4prarhaV62id0
    ntp_server: 0.us.pool.ntp.org
    disk: Micron_9200_MTFDHAL1T6TCU
    ipmi_addresses:
#      - 10.10.0.44
      - 10.10.0.45
      - 10.10.0.46
      - 10.10.0.47
      - 10.10.0.48
      - 10.10.0.49
      - 10.10.0.50
      - 10.10.0.51
      - 10.10.0.52
      - 10.10.0.53
      - 10.10.0.54
      - 10.10.0.55
    networks:
      bonds: false
      bridge: false
      vlan: false
      interfaces:
        enp97s0f0:
          network: management
          primary: true
          bridge: false
          vlan: false
        enp113s0f0:
          network: sfe
          primary: false
          bridge: false
          vlan: false
        enp97s0f1:
          network: public
          primary: false
          bridge: false
          vlan: false
        enp113s0f1:
          network: private
          primary: false
          bridge: false
          vlan: false
  computev3:
    role: compute
    os: ubuntu1804
    macs:
      - 0c:c4:7a:fe:2e:18
      - 0c:c4:7a:fe:2c:d8
      - 0c:c4:7a:fe:30:10
      - 0c:c4:7a:fe:2d:10
      - 0c:c4:7a:fe:2f:b8
      - 0c:c4:7a:fe:2f:ec
      - 0c:c4:7a:fe:2e:54
      - 0c:c4:7a:fe:2e:88
      - 0c:c4:7a:fe:2e:84
      - 0c:c4:7a:fe:30:18
      - 0c:c4:7a:fe:2e:8c
      - 0c:c4:7a:fe:2f:a8
    interface: enp97s0f0
    proxy: pull_from_mine
    root_password_crypted: $6$sSXsfvsKhwy$RrINorhH4lNeNdNbi/vHqCAApM8ID9Lhvmzs6OQMO4791igXZIrhWg6Kyi7XPRGhIZOgGUdCx4prarhaV62id0
    ntp_server: 0.us.pool.ntp.org
    disk: Micron_9200_MTFDHAL1T6TCU
    ipmi_addresses:
      - 10.10.0.56
      - 10.10.0.57
      - 10.10.0.58
      - 10.10.0.59
      - 10.10.0.60
      - 10.10.0.61
      - 10.10.0.62
      - 10.10.0.63
      - 10.10.0.64
      - 10.10.0.65
      - 10.10.0.66
      - 10.10.0.67
    networks:
      bonds: false
      bridge: false
      vlan: false
      interfaces:
        enp97s0f0:
          network: management
          primary: true
          bridge: false
          vlan: false
        enp113s0f0:
          network: sfe
          primary: false
          bridge: false
          vlan: false
        enp97s0f1:
          network: public
          primary: false
          bridge: false
          vlan: false
        enp113s0f1:
          network: private
          primary: false
          bridge: false
          vlan: false
  computev4:
    role: compute
    os: ubuntu1804
    macs:
      - ac:1f:6b:c4:40:96
      - ac:1f:6b:c4:41:9a
      - ac:1f:6b:c4:41:82
      - ac:1f:6b:c4:42:4a
      - ac:1f:6b:c4:42:46
      - ac:1f:6b:c4:42:5a
      - ac:1f:6b:c4:41:aa
      - ac:1f:6b:c4:41:86
      - ac:1f:6b:c4:42:5e
      - ac:1f:6b:c4:42:6a
      - ac:1f:6b:c4:40:b6
      - ac:1f:6b:c4:40:aa
    interface: enp129s0f1
    proxy: pull_from_mine
    root_password_crypted: $6$sSXsfvsKhwy$RrINorhH4lNeNdNbi/vHqCAApM8ID9Lhvmzs6OQMO4791igXZIrhWg6Kyi7XPRGhIZOgGUdCx4prarhaV62id0
    ntp_server: 0.us.pool.ntp.org
    disk: INTEL SSDPE2KX010T8
    ipmi_addresses:
      - 10.10.0.68
      - 10.10.0.69
      - 10.10.0.70
      - 10.10.0.71
      - 10.10.0.72
      - 10.10.0.73
      - 10.10.0.74
      - 10.10.0.75
      - 10.10.0.76
      - 10.10.0.77
      - 10.10.0.78
      - 10.10.0.79
    networks:
      bonds: false
      bridge: false
      vlan: false
      interfaces:
        enp129s0f1:
          network: management
          primary: true
          bridge: false
          vlan: false
        enp129s0f0:
          network: sfe
          primary: false
          bridge: false
          vlan: false
        enp193s0f0:
          network: public
          primary: false
          bridge: false
          vlan: false
        enp193s0f1:
          network: private
          primary: false
          bridge: false
          vlan: false
  computev5:
    role: compute
    os: ubuntu1804
    macs:
      - 3c:ec:ef:4a:64:40
      - 3c:ec:ef:4a:20:64
      - 3c:ec:ef:4a:15:64
      - 3c:ec:ef:4a:63:28
      - 3c:ec:ef:4a:24:d8
      - 3c:ec:ef:4a:64:64
      - 3c:ec:ef:4a:26:84
      - 3c:ec:ef:4a:64:34
      - 3c:ec:ef:4a:64:4c
      - 3c:ec:ef:4a:64:20
      - 3c:ec:ef:4a:63:48
      - 3c:ec:ef:4a:20:bc
    interface: enp161s0f0
    proxy: pull_from_mine
    root_password_crypted: $6$sSXsfvsKhwy$RrINorhH4lNeNdNbi/vHqCAApM8ID9Lhvmzs6OQMO4791igXZIrhWg6Kyi7XPRGhIZOgGUdCx4prarhaV62id0
    ntp_server: 0.us.pool.ntp.org
    disk: INTEL SSDPE2KX010T8
    ipmi_addresses:
      - 10.10.0.80
      - 10.10.0.81
      - 10.10.0.82
      - 10.10.0.83
      - 10.10.0.84
      - 10.10.0.85
      - 10.10.0.86
      - 10.10.0.87
      - 10.10.0.88
      - 10.10.0.89
      - 10.10.0.90
      - 10.10.0.91
    networks:
      bonds: false
      bridge: false
      vlan: false
      interfaces:
        enp161s0f0:
          network: management
          primary: true
          bridge: false
          vlan: false
        enp161s0f1:
          network: sfe
          primary: false
          bridge: false
          vlan: false
        enp129s0f0:
          network: public
          primary: false
          bridge: false
          vlan: false
        enp129s0f1:
          network: private
          primary: false
          bridge: false
          vlan: false
  containerv1:
    role: container
    os: ubuntu1804
    macs:
      - 0c:c4:7a:f9:8e:18
    interface: ens2f0np0
    proxy: pull_from_mine
    root_password_crypted: $6$sSXsfvsKhwy$RrINorhH4lNeNdNbi/vHqCAApM8ID9Lhvmzs6OQMO4791igXZIrhWg6Kyi7XPRGhIZOgGUdCx4prarhaV62id0
    ntp_server: 0.us.pool.ntp.org
    disk: INTEL SSDSC2BA40
    ipmi_addresses:
      - 10.10.0.43
    networks:
      bonds: false
      bridge: false
      vlan: false
      interfaces:
        ens2f0np0:
          network: management
          primary: true
          bridge: false
          vlan: false
        ens2f1np1:
          network: sfe
          primary: false
          bridge: false
          vlan: false
        ens2f3np3:
          network: public
          primary: false
          bridge: false
          vlan: false
        ens2f2np2:
          network: private
          primary: false
          bridge: false
          vlan: false
  containerv2:
    role: container
    os: ubuntu1804
    macs:
      - 0c:c4:7a:fe:30:0c
    interface: enp97s0f0
    proxy: pull_from_mine
    root_password_crypted: $6$sSXsfvsKhwy$RrINorhH4lNeNdNbi/vHqCAApM8ID9Lhvmzs6OQMO4791igXZIrhWg6Kyi7XPRGhIZOgGUdCx4prarhaV62id0
    ntp_server: 0.us.pool.ntp.org
    disk: Micron_9200_MTFDHAL1T6TCU
    ipmi_addresses:
      - 10.10.0.44
    networks:
      bonds: false
      bridge: false
      vlan: false
      interfaces:
        enp97s0f0:
          network: management
          primary: true
          bridge: false
          vlan: false
        enp113s0f0:
          network: sfe
          primary: false
          bridge: false
          vlan: false
        enp97s0f1:
          network: public
          primary: false
          bridge: false
          vlan: false
        enp113s0f1:
          network: private
          primary: false
          bridge: false
          vlan: false
